pub struct CmsgRequests(/* private fields */);Implementations
Sourceimpl CmsgRequests
impl CmsgRequests
Sourcepub const IP_TOS: CmsgRequests
pub const IP_TOS: CmsgRequests
Identifies whether the IP_RECVTOS control message is requested.
Sourcepub const IP_TTL: CmsgRequests
pub const IP_TTL: CmsgRequests
Identifies whether the IP_RECVTTL control message is requested.
Sourcepub const IPV6_TCLASS: CmsgRequests
pub const IPV6_TCLASS: CmsgRequests
Identifies whether the IPV6_RECVTCLASS control message is requested.
Sourcepub const IPV6_HOPLIMIT: CmsgRequests
pub const IPV6_HOPLIMIT: CmsgRequests
Identifies whether the IPV6_RECVHOPLIMIT control message is requested.
Sourcepub const IPV6_PKTINFO: CmsgRequests
pub const IPV6_PKTINFO: CmsgRequests
Identifies whether the IPV6_RECVPKTINFO control message is requested.
Sourcepub const IP_RECVORIGDSTADDR: CmsgRequests
pub const IP_RECVORIGDSTADDR: CmsgRequests
Identifies whether the IP_RECVORIGDSTADDR control message is requested.
Sourcepub const IP_PKTINFO: CmsgRequests
pub const IP_PKTINFO: CmsgRequests
Identifies whether the IP_PKTINFO control message is requested.
Sourceimpl CmsgRequests
impl CmsgRequests
Sourcepub const fn empty() -> CmsgRequests
pub const fn empty() -> CmsgRequests
Get a flags value with all bits unset.
Sourcepub const fn all() -> CmsgRequests
pub const fn all() -> CmsgRequests
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<CmsgRequests>
pub const fn from_bits(bits: u32) -> Option<CmsgRequests>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> CmsgRequests
pub const fn from_bits_truncate(bits: u32) -> CmsgRequests
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> CmsgRequests
pub const fn from_bits_retain(bits: u32) -> CmsgRequests
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<CmsgRequests>
pub fn from_name(name: &str) -> Option<CmsgRequests>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: CmsgRequests) -> bool
pub const fn intersects(&self, other: CmsgRequests) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: CmsgRequests) -> bool
pub const fn contains(&self, other: CmsgRequests) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: CmsgRequests)
pub fn insert(&mut self, other: CmsgRequests)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: CmsgRequests)
pub fn remove(&mut self, other: CmsgRequests)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: CmsgRequests)
pub fn toggle(&mut self, other: CmsgRequests)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: CmsgRequests, value: bool)
pub fn set(&mut self, other: CmsgRequests, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: CmsgRequests) -> CmsgRequests
pub const fn intersection(self, other: CmsgRequests) -> CmsgRequests
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: CmsgRequests) -> CmsgRequests
pub const fn union(self, other: CmsgRequests) -> CmsgRequests
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: CmsgRequests) -> CmsgRequests
pub const fn difference(self, other: CmsgRequests) -> CmsgRequests
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: CmsgRequests) -> CmsgRequests
pub const fn symmetric_difference(self, other: CmsgRequests) -> CmsgRequests
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> CmsgRequests
pub const fn complement(self) -> CmsgRequests
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl CmsgRequests
impl CmsgRequests
Sourcepub const fn iter(&self) -> Iter<CmsgRequests> ⓘ
pub const fn iter(&self) -> Iter<CmsgRequests> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<CmsgRequests> ⓘ
pub const fn iter_names(&self) -> IterNames<CmsgRequests> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl CmsgRequests
impl CmsgRequests
pub fn from_bits_allow_unknown(bits: u32) -> CmsgRequests
pub fn has_unknown_bits(&self) -> bool
pub fn get_unknown_bits(&self) -> u32