pub struct InterfaceFlags(/* private fields */);Expand description
Bits representing the interface flags as returned by the SIOCGIFFLAGS ioctl
operation. These bitmasks are intended to track the C API definition. For
example, InterfaceFlags.UP corresponds to IFF_UP, etc.
Implementations
Sourceimpl InterfaceFlags
impl InterfaceFlags
pub const UP: InterfaceFlags
pub const BROADCAST: InterfaceFlags
pub const DEBUG: InterfaceFlags
pub const LOOPBACK: InterfaceFlags
pub const POINTTOPOINT: InterfaceFlags
pub const NOTRAILERS: InterfaceFlags
pub const RUNNING: InterfaceFlags
pub const NOARP: InterfaceFlags
pub const PROMISC: InterfaceFlags
pub const ALLMULTI: InterfaceFlags
pub const LEADER: InterfaceFlags
pub const FOLLOWER: InterfaceFlags
pub const MULTICAST: InterfaceFlags
pub const PORTSEL: InterfaceFlags
pub const AUTOMEDIA: InterfaceFlags
pub const DYNAMIC: InterfaceFlags
Sourceimpl InterfaceFlags
impl InterfaceFlags
Sourcepub const fn empty() -> InterfaceFlags
pub const fn empty() -> InterfaceFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> InterfaceFlags
pub const fn all() -> InterfaceFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<InterfaceFlags>
pub const fn from_bits(bits: u16) -> Option<InterfaceFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> InterfaceFlags
pub const fn from_bits_truncate(bits: u16) -> InterfaceFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> InterfaceFlags
pub const fn from_bits_retain(bits: u16) -> InterfaceFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<InterfaceFlags>
pub fn from_name(name: &str) -> Option<InterfaceFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: InterfaceFlags) -> bool
pub const fn intersects(&self, other: InterfaceFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: InterfaceFlags) -> bool
pub const fn contains(&self, other: InterfaceFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: InterfaceFlags)
pub fn insert(&mut self, other: InterfaceFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: InterfaceFlags)
pub fn remove(&mut self, other: InterfaceFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: InterfaceFlags)
pub fn toggle(&mut self, other: InterfaceFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: InterfaceFlags, value: bool)
pub fn set(&mut self, other: InterfaceFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: InterfaceFlags) -> InterfaceFlags
pub const fn intersection(self, other: InterfaceFlags) -> InterfaceFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: InterfaceFlags) -> InterfaceFlags
pub const fn union(self, other: InterfaceFlags) -> InterfaceFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: InterfaceFlags) -> InterfaceFlags
pub const fn difference(self, other: InterfaceFlags) -> InterfaceFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: InterfaceFlags) -> InterfaceFlags
pub const fn symmetric_difference(self, other: InterfaceFlags) -> InterfaceFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> InterfaceFlags
pub const fn complement(self) -> InterfaceFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl InterfaceFlags
impl InterfaceFlags
Sourcepub const fn iter(&self) -> Iter<InterfaceFlags> ⓘ
pub const fn iter(&self) -> Iter<InterfaceFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<InterfaceFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<InterfaceFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.