pub struct SendMsgFlags(/* private fields */);Implementations
Sourceimpl SendMsgFlags
impl SendMsgFlags
pub const RESERVED: SendMsgFlags
Sourceimpl SendMsgFlags
impl SendMsgFlags
Sourcepub const fn empty() -> SendMsgFlags
pub const fn empty() -> SendMsgFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> SendMsgFlags
pub const fn all() -> SendMsgFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<SendMsgFlags>
pub const fn from_bits(bits: u16) -> Option<SendMsgFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> SendMsgFlags
pub const fn from_bits_truncate(bits: u16) -> SendMsgFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> SendMsgFlags
pub const fn from_bits_retain(bits: u16) -> SendMsgFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<SendMsgFlags>
pub fn from_name(name: &str) -> Option<SendMsgFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: SendMsgFlags) -> bool
pub const fn intersects(&self, other: SendMsgFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: SendMsgFlags) -> bool
pub const fn contains(&self, other: SendMsgFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: SendMsgFlags)
pub fn insert(&mut self, other: SendMsgFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: SendMsgFlags)
pub fn remove(&mut self, other: SendMsgFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: SendMsgFlags)
pub fn toggle(&mut self, other: SendMsgFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: SendMsgFlags, value: bool)
pub fn set(&mut self, other: SendMsgFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: SendMsgFlags) -> SendMsgFlags
pub const fn intersection(self, other: SendMsgFlags) -> SendMsgFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: SendMsgFlags) -> SendMsgFlags
pub const fn union(self, other: SendMsgFlags) -> SendMsgFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: SendMsgFlags) -> SendMsgFlags
pub const fn difference(self, other: SendMsgFlags) -> SendMsgFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: SendMsgFlags) -> SendMsgFlags
pub const fn symmetric_difference(self, other: SendMsgFlags) -> SendMsgFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> SendMsgFlags
pub const fn complement(self) -> SendMsgFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl SendMsgFlags
impl SendMsgFlags
Sourcepub const fn iter(&self) -> Iter<SendMsgFlags> ⓘ
pub const fn iter(&self) -> Iter<SendMsgFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<SendMsgFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<SendMsgFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.